@@ -5,23 +5,21 @@
 **
 ** Copyright (C) 2002-2004 Steve Lhomme.  All rights reserved.
 **
-** This file may be distributed under the terms of the Q Public License
-** as defined by Trolltech AS of Norway and appearing in the file
-** LICENSE.QPL included in the packaging of this file.
+** This library is free software; you can redistribute it and/or
+** modify it under the terms of the GNU Lesser General Public
+** License as published by the Free Software Foundation; either
+** version 2.1 of the License, or (at your option) any later version.
+** 
+** This library is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+** Lesser General Public License for more details.
+** 
+** You should have received a copy of the GNU Lesser General Public
+** License along with this library; if not, write to the Free Software
+** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **
-** This file may be distributed and/or modified under the terms of the
-** GNU General Public License version 2 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.
-**
-** Licensees holding an other license may use this file in accordance with 
-** the Agreement provided with the Software.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-**
-** See http://www.matroska.org/license/qpl/ for QPL licensing information.
-** See http://www.matroska.org/license/gpl/ for GPL licensing information.
+** See http://www.matroska.org/license/lgpl/ for LGPL licensing information.
 **
 ** Contact license@matroska.org if any conditions of this licensing are
 ** not clear to you.
@@ -30,7 +28,7 @@
 
 /*!
 	\file
-	\version \$Id: EbmlElement.cpp,v 1.16 2004/01/10 15:31:03 robux4 Exp $
+	\version \$Id: EbmlElement.cpp,v 1.18 2004/04/14 23:16:31 robux4 Exp $
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 */
 
@@ -264,6 +262,10 @@ EbmlElement * EbmlElement::FindNextID(IOCallback & DataStream, const EbmlCallbac
 		aSizePosition = DataStream.getFilePointer();
 		uint32 _SizeLength;
 		do {
+			if (PossibleSizeLength >= 8)
+				// Size is larger than 8 bytes
+				return NULL;
+
 			ReadSize += DataStream.read(&PossibleSize[PossibleSizeLength++], 1);
 			_SizeLength = PossibleSizeLength;
 			SizeFound = ReadCodedSizeValue(&PossibleSize[0], _SizeLength, SizeUnknown);
